# data structure

* files 
    * cc-logs 
        * ControlCenter-[Date-ID?].log
        * serial[Year-Month-Day]-COM[ID]-r.log
        * serial[Year-Month-Day]-COM[ID]-r.raw
    * data
        * seanav-[YYYYMMDDHHMMSS].bin
    * debug
        * gavia.pylog.[YYYYMMDD]-[HHMMSS].gz
    * log
        * [Instrument]-[YYYYMMDD]-[HHMMSS].xml.gz

* points.fs 
* points.fs.index
* points.fs.lock
* points.fs.tmp